@@ -15,13 +15,14 @@
 """
 
 import logging as log
+import os
 import signal
 import sys
-from datetime import datetime
 from textwrap import dedent
 
 from hspylib.core.enums.charset import Charset
 from hspylib.core.tools.commons import syserr
+from hspylib.core.tools.zoned_datetime import now
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.application.version import Version
 
@@ -52,7 +53,7 @@ class Main(Application):
 
         self._with_chained_args('operation', 'the Vault operation to process') \
             .argument('list', 'list all entries matching the given filter criteria, if specified') \
-                .add_argument('filter', "filter the listed vault entries by it's name", nargs='?') \
+                .add_argument('filter', "filter the listed vault entries by it's name", nargs='*') \
             .argument('get', 'get a vault entry') \
                 .add_argument('name', 'the name of the vault entry which identifies it') \
             .argument('del', 'delete an existing vault entry') \
@@ -75,7 +76,7 @@ class Main(Application):
         Settings ==============================
                 VAULT_USER: {VaultConfig.INSTANCE.vault_user()}
                 VAULT_FILE: {VaultConfig.INSTANCE.vault_file()}
-                STARTED: {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}
+                STARTED: {now("%Y-%m-%d %H:%M:%S")}
         '''))
 
         signal.signal(signal.SIGINT, self._abort)
@@ -88,6 +89,9 @@ class Main(Application):
     def _cleanup(self) -> None:
         """TODO"""
         self.vault.close()
+        unlocked = self.vault.configs.unlocked_vault_file()
+        if os.path.exists(unlocked):
+            os.remove(unlocked)
 
     def _abort(self, signum=0, frame=None) -> None:
         """TODO"""
